@@ -1,7 +1,6 @@
 from optparse import make_option
 from django.core.management.base import BaseCommand
 from django.db import transaction
-from django.contrib.auth.models import User
 from avocado.conf import settings
 from avocado.history.models import Revision
 
@@ -10,13 +9,13 @@ class Command(BaseCommand):
     help = 'Utilities for managing the history API'
 
     option_list = BaseCommand.option_list + (
-        make_option('--cull', action='store_true',
-            help='Culls entries that exceeds the maximum allowed history size '
-                'for each instance.'),
+        make_option('--cull', action='store_true', help='Culls entries that '
+                    'exceeds the maximum allowed history size for each '
+                    'instance.'),
 
-        make_option('--max-size', type=int,
-            help='Specify the max history size for commands that require it. '
-                'Defaults to HISTORY_MAX_SIZE.'),
+        make_option('--max-size', type=int, help='Specify the max history '
+                    'size for commands that require it. Defaults to '
+                    'HISTORY_MAX_SIZE.'),
     )
 
     @transaction.commit_on_success
